/***************************************************************************
 *   Copyright (C) 2005-2006 by                                            *
 *                                                                         *
 *      Stefan Schwarzer <sxs@morphine.tv>                                 *
 *      Guido Madaus     <bere@morphine.tv>                                *
 *      Jens Schneider   <pupeider@morphine.tv>                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License.        *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "mmsmixerplugin.h"

MMS_EXPORT_BACKEND_PLUGIN(MMSMixerPlugin);

MMSMixerPlugin::MMSMixerPlugin() {
	mixer = NULL;
}
      
MMSMixerPlugin::~MMSMixerPlugin() {
	if (mixer) delete mixer;
}

bool MMSMixerPlugin::initialize(MMSPluginData data) {

	try {
        logger.setIdentity("MMSMixerPlugin");
        
        /* save my plugin data */
        this->plugindata = data;
        
        logger.writeLog("initializing...");
        
        this->window = (MMSPopupWindow*)dm.loadDialog(this->plugindata.getPath() + "/mmsmixer.xml");
        
        this->pBar    = (MMSProgressBar*)dm["pBar"];
        this->message = (MMSLabel*)dm["message"];
        
        subscribeKey(DIKS_PAGE_DOWN);
        subscribeKey(DIKS_PAGE_UP);
        subscribeKey(DIKS_PAUSE);
        
        /*TEST*/
        /*	mmssound = new MMSSound("/mms/sound.mp3");
        	mmssound->play();*/
        /*TEST*/
        
        mixer = new MMSAudioCtrl();
        
        logger.writeLog("initializing finished");
        
    } catch(MMSError *error) {
        logger.writeLog("Abort due to: " + error->getMessage());
    }
	 
	return true;
}

bool MMSMixerPlugin::onEvent(IMMSEvent *event) {
	return false;
}

bool MMSMixerPlugin::shutdown() {
	return true;
}

void MMSMixerPlugin::onSubscriptionKey(DFBInputDeviceKeySymbol key) {
	int	volume;

    try {
        /* key pressed */
        if (key == DIKS_PAGE_DOWN) {
            if (this->window->isShown())
            	mixer->volumeDown();
        	volume=mixer->getVolume();
            this->pBar->setProgress(volume, false);
        	this->message->setText("VOLUME " + iToStr(volume) + "%");
        }
        else
        if (key == DIKS_PAGE_UP) {
            if (this->window->isShown())
            	mixer->volumeUp();
        	volume=mixer->getVolume();
            this->pBar->setProgress(volume, false);
        	this->message->setText("VOLUME " + iToStr(volume) + "%");
        }
        else
        if (key == DIKS_PAUSE) {
            mixer->mute();
        	if (mixer->isMute()) {
                this->pBar->setProgress(0, false);
        		this->message->setText("VOLUME " + iToStr(0) + "%");
        	} else {
        		volume=mixer->getVolume();
                this->pBar->setProgress(volume, false);
        		this->message->setText("VOLUME " + iToStr(volume) + "%");
        	}
        }

        this->window->show();

    } catch(MMSError *error) {
        logger.writeLog("Abort due to: " + error->getMessage());
    }
     
}

void MMSMixerPlugin::subscribeKey(DFBInputDeviceKeySymbol key) {
	MMSInputSubsciption *subscription = new MMSInputSubsciption(key);
	subscription->callback.connect(sigc::mem_fun(this, &MMSMixerPlugin::onSubscriptionKey));
	subscription->registerMe();
}

