/***************************************************************************
 *   Copyright (C) 2005-2006 by                                            *
 *                                                                         *
 *      Stefan Schwarzer <sxs@morphine.tv>                                 *
 *      Guido Madaus     <bere@morphine.tv>                                *
 *      Jens Schneider   <pupeider@morphine.tv>                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License.        *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "mmsmusicthread.h"

#ifdef USE_MMSSOUND
MMSMusicThread::MMSMusicThread(MMSSound *mmssound) {
#else
MMSMusicThread::MMSMusicThread(MMSVideo *mmssound) {
#endif
    this->mmssound = mmssound;
    this->length = 0;
    this->label = NULL;
    this->firstStart = false;
}

void MMSMusicThread::setFirstStart(bool firstStart) {
    this->firstStart = firstStart;
}

void MMSMusicThread::setVal(double length, MMSLabel *label) {
    this->length = length;
    this->label = label;
    this->firstStart = false;
}

void MMSMusicThread::threadMain() {
    if (this->firstStart) {
        /* wait a while */
        int cnt=0;
        while ((this->firstStart)&&(cnt++<30))
            msleep(100);
        /* anybody has break the start process? */
        if (this->firstStart == false)
            return;
        /* fire the event */
        this->firstStart = false;
        onFirstStart.emit(this);
    }
    else {
        double pos;
        int leftsave=-1;
        bool isplaying;
        do {
            msleep(250);
            if ((isplaying=this->mmssound->isPlaying())) {
                if (this->length>0) {
                    if (this->mmssound->getPos(&pos)) {
                        double left = this->length - pos;
                        if ((int)left != leftsave) {
                            leftsave = (int)left;
                            char tb[32];
                            sprintf(tb, "%02d:%02d", leftsave/60, leftsave%60);
                            label->setText(tb);
                        }
                    }
                }
            }
        } while(isplaying);
        onStop.emit(this);
    }
}

