/***************************************************************************
 *   Copyright (C) 2005-2006 by                                            *
 *                                                                         *
 *      Stefan Schwarzer <sxs@morphine.tv>                                 *
 *      Guido Madaus     <bere@morphine.tv>                                *
 *      Jens Schneider   <pupeider@morphine.tv>                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License.        *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "mmstvchannelimportplugin.h"

MMS_EXPORT_IMPORT_PLUGIN(MMSTVChannelImportPlugin);

MMSTVChannelImportPlugin::MMSTVChannelImportPlugin() {
}
      
MMSTVChannelImportPlugin::~MMSTVChannelImportPlugin() {
}

bool MMSTVChannelImportPlugin::initialize(MMSPluginData plugindata) {
    MMSConfigData   *config;
    DataSource      confsource;
    DataSource      datasource;

    try {
        logger.setIdentity("MMSTVChannelImportPlugin");
        
        /* build data source */
        config = new MMSConfigData();
        confsource.setFilename(config->getConfigDBName());
        datasource.setFilename(config->getDataDBName());
        delete config;
        
        /* save my plugin data */
        this->plugindata = plugindata;
        
        /* get access to source service (config data) */
        iss = new MMSImportSourceService(confsource);
        
        /* get access to tvchannel service (my data) */
        tcs = new MMSTVChannelService(datasource);
    
    } catch(MMSError *error) {
        logger.writeLog("Abort due to: " + error->getMessage());
    }

    return true;
}

bool MMSTVChannelImportPlugin::execute() {
    vector<MMSImportSourceData *>   sourcesList;

    logger.writeLog("IMPORTING...");

    try {
        /* get all import sources */
        sourcesList = iss->getImportSourcesByPlugin(&(this->plugindata));
    
        /* through all sources */
        for (unsigned i=0;i<sourcesList.size();i++) {
            /* load the source */
            logger.writeLog("Load file " + sourcesList.at(i)->getSource());
            MMSFile *myfile = new MMSFile(sourcesList.at(i)->getSource());
            if (!myfile) {
                logger.writeLog("Load file " + sourcesList.at(i)->getSource() + "failed");
                continue;
            }
            char *ptr,*ptrsave;
            while (myfile->getLine(&ptr)) {
                /* extract data from string */
                ptrsave = ptr;
                char *pos;
                if ((pos=strstr(ptr, ":"))) {
                    string s=ptr;
                    s = s.substr(0, pos-ptr);
                    logger.writeLog("Work with channel '" + s + "'");

                    /* check if channel already exist */
                    MMSTVChannelData *channel;
                    if ((channel = tcs->getChannelByName(s))==NULL) {
                        logger.writeLog(">import the channel");

                        /* new object */
                        MMSTVChannelData *data = new MMSTVChannelData();
                        data->setSourceId(sourcesList.at(i)->getId());
                        data->setName(s);

                        /* search for sid (service id) pos */
                        char *sidpos=strrchr(ptr,':')+1;
                        data->setSID(atoi(sidpos));
                        
                        /* add the whole line */
                        data->setLine(ptrsave);
        
                        /* save it */
                        tcs->setChannel(data);
                    }
                    else {
                        logger.writeLog(">the channel is already imported");
                        delete channel;
                    }
    
                }
    
                /* free memory */
                free(ptrsave);
            }
            delete myfile;
        }
    
        /* free memory */
        for (unsigned i=0;i<sourcesList.size();i++)
            delete sourcesList.at(i);

    } catch(MMSError *error) {
        logger.writeLog("Abort due to: " + error->getMessage());
    }

    return true;
}

bool MMSTVChannelImportPlugin::shutdown() {
    delete iss;
    delete tcs;
    return true;
}

bool MMSTVChannelImportPlugin::cleanUp() {
    return true;
}


